==> mocca_edc-0.1.12-py3-none-any.whl: mocca_subject/admin/drug_refill_chol_admin.py <==
from django.contrib import admin
from django.utils.safestring import mark_safe
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin, TabularInlineMixin
from respond_model.modeladmin_mixins import DrugSupplyInlineMixin

from ..admin_site import mocca_subject_admin
from ..forms import DrugRefillCholForm, DrugSupplyCholForm
from ..models import DrugRefillChol, DrugSupplyChol
from .modeladmin_mixins import CrfModelAdminMixin


class DrugSupplyCholInline(DrugSupplyInlineMixin, TabularInlineMixin, admin.TabularInline):
    model = DrugSupplyChol
    form = DrugSupplyCholForm
    min_num = 1
    insert_after = "return_in_days"


@admin.register(DrugRefillChol, site=mocca_subject_admin)
class DrugRefillCholAdmin(CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin):
    form = DrugRefillCholForm

    additional_instructions = mark_safe(
        '<span style="color:orange">Note: Medications CRF must be completed first.</span>'
    )

    inlines = [DrugSupplyCholInline]
    add_form_template = "admin/custom_inline/change_form.html"
    change_form_template = "admin/custom_inline/change_form.html"

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Hypertension Drug Refill Today",
            {
                "fields": (
                    "rx",
                    "rx_other",
                    "rx_modified",
                    "modifications",
                    "modifications_other",
                    "modifications_reason",
                    "modifications_reason_other",
                    "return_in_days",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = ["rx", "modifications", "modifications_reason"]

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "rx_modified": admin.VERTICAL,
    }

==> mocca_edc-0.1.23-py3-none-any.whl: mocca_subject/admin/drug_refill_chol_admin.py <==
from django.contrib import admin
from django.utils.safestring import mark_safe
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import mocca_subject_admin
from ..forms import DrugRefillCholForm
from ..models import DrugRefillChol
from .modeladmin_mixins import CrfModelAdminMixin


@admin.register(DrugRefillChol, site=mocca_subject_admin)
class DrugRefillCholAdmin(CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin):
    form = DrugRefillCholForm

    additional_instructions = mark_safe(
        '<span style="color:orange">Note: Medications CRF must be completed first.</span>'
    )

    add_form_template = "admin/custom_inline/change_form.html"
    change_form_template = "admin/custom_inline/change_form.html"

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Hypertension Drug Refill Today",
            {
                "fields": (
                    "rx",
                    "rx_other",
                    "rx_modified",
                    "modifications",
                    "modifications_other",
                    "modifications_reason",
                    "modifications_reason_other",
                    "return_in_days",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = ["rx", "modifications", "modifications_reason"]

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "rx_modified": admin.VERTICAL,
    }
